==> 0.0.1.tar.gz: lib/code_widgets/otp/otp_field.dart <==
import 'package:auto_size_text_pk/auto_size_text_pk.dart';
import 'package:flutter/material.dart';

class OtpField extends StatelessWidget {
  final String otp;
  final FocusNode focusNode;
  final isFieldHasFocus;
  final void Function(String) onChanged;
  final String? error;
  final TextEditingController? controller;
  final bool obscureText;
  final Color? backgroundColor;
  OtpField({
    required this.focusNode,
    required this.otp,
    required this.isFieldHasFocus,
    required this.onChanged,
    this.error,
    this.controller,
    this.obscureText = false,
    this.backgroundColor,
  });

  @override
  Widget build(BuildContext context) {
    bool _isHasError = error != null;
    return Column(
      children: [
        Stack(
          alignment: Alignment.center,
          children: [
            AbsorbPointer(
              child: TextFormField(
                focusNode: focusNode,
                controller: controller,
                decoration: InputDecoration.collapsed(hintText: ''),
                maxLength: 6,
                enableInteractiveSelection: false,
                onChanged: onChanged,
                keyboardType: TextInputType.number,
                buildCounter: (
                  _, {
                  required currentLength,
                  maxLength,
                  required isFocused,
                }) =>
                    SizedBox.shrink(),
              ),
            ),
            InkWell(
              splashColor: Colors.transparent,
              highlightColor: Colors.transparent,
              onTap: () async {
                if (isFieldHasFocus) {
                  //Handle case keyboard is closed but field still has focus
                  FocusManager.instance.primaryFocus?.unfocus();
                  await Future.delayed(Duration(milliseconds: 200));
                }
                focusNode.requestFocus();
              },
              child: Container(
                color: backgroundColor,
                child: Row(
                  mainAxisAlignment: MainAxisAlignment.spaceEvenly,
                  children: List.generate(6, (index) {
                    final bool _isOnTheLast = otp.length == 6 && index == 5;
                    final bool _isFocus = _isOnTheLast || index == otp.length;
                    return _OtpDigitField(
                      text: getOtpDigitByIndex(index),
                      isFocus: isFieldHasFocus && _isFocus,
                      hasError: _isHasError,
                      obscureText: obscureText,
                    );
                  }).toList(),
                ),
              ),
            ),
          ],
        ),
        if (_isHasError)
          Padding(
            padding: EdgeInsets.only(top: 10),
            child: Text(
              error!,
              style: TextStyle(color: Colors.red[800]),
            ),
          ),
      ],
    );
  }

  String getOtpDigitByIndex(int index) {
    return otp.length <= index ? '' : otp[index];
  }
}

class _OtpDigitField extends StatelessWidget {
  final String text;
  final bool isFocus;
  final bool hasError;
  final bool obscureText;
  final Color? backgroundColor;
  final Color? focusedColor;
  final Color? shadowColor;
  final Color? textColor;
  const _OtpDigitField({
    Key? key,
    required this.text,
    required this.isFocus,
    required this.hasError,
    required this.obscureText,
    this.backgroundColor,
    this.focusedColor,
    this.shadowColor,
    this.textColor,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    double width = hasError
        ? 1.5
        : isFocus
            ? 1.7
            : 1;
    Color color = hasError
        ? Colors.red[800] ?? Colors.red
        : isFocus
            ? focusedColor ?? Colors.black
            : const Color(4278190080);
    return Container(
        height: 40,
        width: 40,
        decoration: BoxDecoration(
          color: backgroundColor,
          border: Border.all(
            width: width,
            color: color,
          ),
          boxShadow: !isFocus
              ? null
              : [
                  BoxShadow(
                    color: shadowColor ?? Colors.grey,
                    blurRadius: 2,
                    spreadRadius: 2,
                    offset: Offset(0, 0),
                  )
                ],
        ),
        child: text.isEmpty
            ? SizedBox.shrink()
            : Center(
                child: !obscureText
                    ? AutoSizeText(
                        text,
                        style: TextStyle(
                            height: 1.1,
                            fontSize: 28,
                            color: textColor ?? Colors.black),
                      )
                    : Icon(Icons.circle, size: 18),
              ));
  }
}

==> 0.0.3.tar.gz: lib/code_widgets/otp/otp_field.dart <==
import 'package:auto_size_text_pk/auto_size_text_pk.dart';
import 'package:flutter/material.dart';

class OtpField extends StatelessWidget {
  final String otp;
  final FocusNode focusNode;
  final bool isFieldHasFocus;
  final Function(String) onChanged;
  final String? error;
  final TextEditingController? controller;
  final bool obscureText;
  final Color? backgroundColor;
  final int length;

  OtpField({
    required this.focusNode,
    required this.otp,
    required this.isFieldHasFocus,
    required this.onChanged,
    this.error,
    this.controller,
    this.obscureText = false,
    this.backgroundColor,
    this.length = 6,
  });

  @override
  Widget build(BuildContext context) {
    bool _isHasError = error != null;
    return Column(
      children: [
        Stack(
          alignment: Alignment.center,
          children: [
            AbsorbPointer(
              child: TextFormField(
                focusNode: focusNode,
                controller: controller,
                decoration: InputDecoration.collapsed(hintText: ''),
                maxLength: length,
                enableInteractiveSelection: false,
                onChanged: onChanged,
                keyboardType: TextInputType.number,
                buildCounter: (
                  _, {
                  required currentLength,
                  maxLength,
                  required isFocused,
                }) =>
                    SizedBox.shrink(),
              ),
            ),
            InkWell(
              splashColor: Colors.transparent,
              highlightColor: Colors.transparent,
              onTap: () async {
                if (isFieldHasFocus) {
                  //Handle case keyboard is closed but field still has focus
                  FocusManager.instance.primaryFocus?.unfocus();
                  await Future.delayed(Duration(milliseconds: 200));
                }
                focusNode.requestFocus();
              },
              child: Container(
                color: backgroundColor,
                child: Row(
                  mainAxisAlignment: MainAxisAlignment.spaceEvenly,
                  children: List.generate(length, (index) {
                    final bool _isOnTheLast =
                        otp.length == length && index == length - 1;
                    final bool _isFocus = _isOnTheLast || index == otp.length;
                    return _OtpDigitField(
                      text: getOtpDigitByIndex(index),
                      isFocus: isFieldHasFocus && _isFocus,
                      hasError: _isHasError,
                      obscureText: obscureText,
                    );
                  }).toList(),
                ),
              ),
            ),
          ],
        ),
        if (_isHasError)
          Padding(
            padding: EdgeInsets.only(top: 10),
            child: Text(
              error!,
              style: TextStyle(color: Colors.red[800]),
            ),
          ),
      ],
    );
  }

  String getOtpDigitByIndex(int index) {
    return otp.length <= index ? '' : otp[index];
  }
}

class _OtpDigitField extends StatelessWidget {
  final String text;
  final bool isFocus;
  final bool hasError;
  final bool obscureText;
  final Color? backgroundColor;
  final Color? focusedColor;
  final Color? shadowColor;
  final Color? textColor;
  const _OtpDigitField({
    Key? key,
    required this.text,
    required this.isFocus,
    required this.hasError,
    required this.obscureText,
    this.backgroundColor,
    this.focusedColor,
    this.shadowColor,
    this.textColor,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    double width = hasError
        ? 1.5
        : isFocus
            ? 1.7
            : 1;
    Color color = hasError
        ? Colors.red[800] ?? Colors.red
        : isFocus
            ? focusedColor ?? Colors.black
            : const Color(4278190080);
    return Container(
        height: 40,
        width: 40,
        decoration: BoxDecoration(
          color: backgroundColor,
          border: Border.all(
            width: width,
            color: color,
          ),
          boxShadow: !isFocus
              ? null
              : [
                  BoxShadow(
                    color: shadowColor ?? Colors.grey,
                    blurRadius: 2,
                    spreadRadius: 2,
                    offset: Offset(0, 0),
                  )
                ],
        ),
        child: text.isEmpty
            ? SizedBox.shrink()
            : Center(
                child: !obscureText
                    ? AutoSizeText(
                        text,
                        style: TextStyle(
                            height: 1.1,
                            fontSize: 28,
                            color: textColor ?? Colors.black),
                      )
                    : Icon(Icons.circle, size: 18),
              ));
  }
}
